==> owncloud-app-contacts-2%3A1.3.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/hu_HU.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Névjegyek",
    "Address book name" : "Címjegyzék neve",
    "Import" : "Importálás",
    "No contacts in here" : "Nincsenek névjegyek",
    "Name" : "Név",
    "Organization" : "Szervezet",
    "Title" : "Cím",
    "Add field ..." : "Mező hozzáadása",
    "Add contact" : "Névjegy hozzáadása",
    "No search result for {query}" : "{query} keresésre nincs találat.",
    "All contacts" : "Összes névjegy",
    "Not grouped" : "Nem csoportosított",
    "Post Office Box" : "Postaláda",
    "Postal Code" : "Irányítószám",
    "City" : "Város",
    "State or province" : "Megye vagy tartomány",
    "Country" : "Ország",
    "Address" : "Cím",
    "(new group)" : "(új csoport)",
    "New contact" : "Új névjegy",
    "{addressbook} shared by {owner}" : "{addressbook} megosztója {owner}",
    "No contacts in file. Only VCard files are allowed." : "A fájl nem tartalmaz névjegyeket. Kizárólag VCard fájlok engedélyezettek.",
    "Nickname" : "Becenév",
    "Notes" : "Jegyzetek",
    "Website" : "Weboldal",
    "Federated Cloud ID" : "Egyesített Felhő Azonosító",
    "Home" : "Otthoni",
    "Work" : "Munkahelyi",
    "Other" : "más",
    "Groups" : "Csoportok",
    "Birthday" : "Születésap",
    "Email" : "E-mail",
    "Instant messaging" : "Azonnali üzenetküldés",
    "Phone" : "Telefonszám",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Otthoni fax",
    "Fax work" : "Munkahelyi fax",
    "Pager" : "Személyhívó",
    "Voice" : "Hang",
    "Social Network" : "Közösségi hálózat",
    "Settings" : "Beállítások"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/hu_HU.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Névjegyek",
    "Address book name" : "Címjegyzék neve",
    "Import" : "Importálás",
    "The selected image is too big (max 1MB)" : "A kiválasztott kép túl nagy (max. 1 MB)!",
    "No contacts in here" : "Nincsenek névjegyek",
    "Name" : "Név",
    "Organization" : "Szervezet",
    "Title" : "Cím",
    "Add field ..." : "Mező hozzáadása",
    "No search result for {query}" : "{query} keresésre nincs találat.",
    "Postal code" : "Irányítószám",
    "City" : "Város",
    "State or province" : "Megye vagy tartomány",
    "Country" : "Ország",
    "Address" : "Cím",
    "(new group)" : "(új csoport)",
    "Last name" : "Vezetéknév",
    "First name" : "Keresztnév",
    "Additional names" : "További nevek",
    "All contacts" : "Összes névjegy",
    "Not grouped" : "Nem csoportosított",
    "New contact" : "Új névjegy",
    "{addressbook} shared by {owner}" : "{addressbook} megosztója {owner}",
    "No contacts in file. Only VCard files are allowed." : "A fájl nem tartalmaz névjegyeket. Kizárólag VCard fájlok engedélyezettek.",
    "Nickname" : "Becenév",
    "Notes" : "Jegyzetek",
    "Website" : "Weboldal",
    "Federated Cloud ID" : "Egyesített Felhő Azonosító",
    "Home" : "Otthoni",
    "Work" : "Munkahelyi",
    "Other" : "más",
    "Groups" : "Csoportok",
    "Birthday" : "Születésap",
    "Email" : "E-mail",
    "Instant messaging" : "Azonnali üzenetküldés",
    "Phone" : "Telefonszám",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Otthoni fax",
    "Fax work" : "Munkahelyi fax",
    "Pager" : "Személyhívó",
    "Voice" : "Hang",
    "Settings" : "Beállítások"
},
"nplurals=2; plural=(n != 1);");
